@@ -1,4 +1,4 @@
-### $Id: groupedData.q,v 1.29 1999/06/18 16:44:03 pinheiro Exp $
+### $Id: groupedData.q,v 1.30 1999/07/27 20:54:27 pinheiro Exp $
 ###
 ###           groupedData - data frame with a grouping structure
 ###
@@ -486,7 +486,7 @@ plot.nffGroupedData <-
              panel.abline(h = y, lwd = dot.line$lwd,
                           lty = dot.line$lty, col = dot.line$col)
              panel.dotplot(x, y)
-           }, key = length(inner) > 0, ...)
+           }, key = length(inner) > 0, grid, ...)
 {
   groupExpr <- deparse(getGroupsFormula(x)[[2]])
   if (is.null(groupLabel <- attr(x[, groupExpr], "label"))) {
