@@ -1,4 +1,4 @@
-/* $Id: nlmefit.c,v 1.46 1999/06/22 19:30:08 bates Exp $ 
+/* $Id: nlmefit.c,v 1.48 1999/07/08 21:29:01 bates Exp $ 
 
    Routines for calculation of the log-likelihood or restricted
    log-likelihood with mixed-effects models.
@@ -565,7 +565,7 @@ internal_loglik(dimPTR dd, double *ZXy, double *DmHalf, longint *RML,
 			DmHalf + (dd->DmOff)[i], qi, (dd->ncol)[i],
 			lglk + i, dc + (dd->SToff)[i][j], ldstr))
 	{ PROBLEM "Singular precision matrix in level %ld, block %ld",
-		  i + 1L, j + 1L  RECOVER(NULL_ENTRY); }
+		  i - (dd->Q), j + 1L  RECOVER(NULL_ENTRY); }
     }
   }
   for(i = 0, accum = 0; i < Q; i++) {
@@ -594,7 +594,7 @@ internal_estimate(dimPTR dd, double *dc)
 		    (dd->ncol)[i], (dd->nrot)[i], (dd->ncol)[Qp1]) != 0)
 	{ 
 	  PROBLEM "Singularity in backsolve at level %ld, block %ld",
-	    i + 1L, j + 1L RECOVER(NULL_ENTRY); 
+	    i - (dd->Q), j + 1L RECOVER(NULL_ENTRY); 
 	}
     }
   }
@@ -2235,13 +2235,13 @@ static struct {			/* Gauss-Newton nonlinear least squares */
   dimPTR dd;
 } nlme;
 
-static long int *
+static longint *
 make_sequential(longint *dest, longint *src, longint n)
 {                    
   /*  copy the pattern from src to dest */
   /*  but in sequential values starting */
   /*  from 0 */
-  long val = 0, *ret = dest, sval;
+  longint val = 0, *ret = dest, sval;
   if (n <= 0) return dest;
   sval = *src++; *dest++ = val;
   while (--n) {
@@ -2311,7 +2311,7 @@ nlme_objective(void)
 static void
 nlme_correction(void)
 {
-  long i, j, nq;
+  longint i, j, nq;
   for(i = 0; i < nlme.dd->N; i++) {
     for(j = 0, nq = 0; j < nlme.dd->Q; j++) {
       nlme.residuals[i] += d_dot_prod(nlme.gradient + (nlme.dd->ZXoff)[j][0] + i, 
@@ -2328,7 +2328,7 @@ nlme_correction(void)
 static double
 nlme_RegSS(double *incr, double *mat)
 {
-  long i, j, nq;
+  longint i, j, nq;
   double regSS = 0, aux = 0, *src;
   for(i = 0; i < nlme.dd->N; i++) {
     for(j = 0, nq = 0, aux = 0; j < nlme.dd->Q; j++) {
@@ -2359,7 +2359,7 @@ nlme_increment(double *incr)
   double regSS, *dc = Calloc(nlme.dd->Srows * nlme.dd->ZXcols, double),
     ll, *dest, *src, 
     *auxGrad = Calloc(nlme.dd->N * (nlme.dd->ZXcols - 1), double);
-  long i, j, start, RML = 0;
+  longint i, j, start, RML = 0;
   if (!sqrt_eps) sqrt_eps = sqrt(DOUBLE_EPS);
   Memcpy(auxGrad, nlme.gradient, (nlme.dd->ZXcols - 1) * nlme.dd->N);
   nlme_correction();
@@ -2456,9 +2456,9 @@ fit_nlme(double *ptheta, double *pDmHalf, longint *pgroups,
 /*  Quinidine model  */
 
 void 
-nlme_one_comp_open (long int *nrow, double *Resp, double *inmat)
+nlme_one_comp_open (longint *nrow, double *Resp, double *inmat)
 {
-  long int i, nn = *nrow;
+  longint i, nn = *nrow;
   double ke, ka, tl = 0, delta, C, Ca, interval,
     *Subject, *Time, *Conc, *Dose, *Interval, *V, *Ka, *Ke,
          sl = DOUBLE_EPS;	/* sl is last subject number, usually */
@@ -2517,9 +2517,9 @@ nlme_one_comp_open (long int *nrow, double *Resp, double *inmat)
 /* Phenobarbital Model */ 
 
 void 
-nlme_one_comp_first (long int *nrow, double *Resp, double *inmat)
+nlme_one_comp_first (longint *nrow, double *Resp, double *inmat)
 {
-  long int i, j, nn = *nrow, mm = 0;
+  longint i, j, nn = *nrow, mm = 0;
   double v, cl, *tl = Calloc(nn, double), *ds = Calloc(nn, double),
     *Subject, *Time, *Dose, *V, *Cl,
          sl = DOUBLE_EPS;	/* sl is last subject number, usually */
@@ -2639,7 +2639,7 @@ gnls_objective(void)
 static double
 gnls_RegSS(double *incr)
 {
-  long i;
+  longint i;
   double regSS = 0, aux;
   for(i = 0; i < gnls.N; i++) {
     aux = d_dot_prod(gnls.gradient + i, gnls.N, incr, 1L, gnls.npar);
@@ -2653,7 +2653,7 @@ gnls_increment(double *incr)
 {
   double regSS = 0, *auxRes;
   QRptr aQR;
-  long i, j, start;
+  longint i, j, start;
   if (!sqrt_eps) sqrt_eps = sqrt(DOUBLE_EPS);
   auxRes = Calloc(gnls.N, double);
   Memcpy(auxRes, gnls.residuals, gnls.N);
